# qNetTI: Quantum Network Topology Inferrer

*Python tools and demos for inferring quantum network topology.*

[![Latest](https://img.shields.io/badge/docs-latest-blue.svg)](https://chitambarlab.github.io/qNetTI/index.html)[![Tests](https://github.com/ChitambarLab/qNetTI/actions/workflows/run_tests.yml/badge.svg?branch=main)](https://github.com/ChitambarLab/qNetTI/actions/workflows/run_tests.yml)[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)[![DOI](https://zenodo.org/badge/581250970.svg)](https://zenodo.org/badge/latestdoi/581250970)

See our preprint titled "Inferring Quantum Network Topology using Local Measurements" for details [https://arxiv.org/abs/2212.07987](https://arxiv.org/abs/2212.07987).

Please review the [documentation](https://chitambarlab.github.io/qNetTI/index.html) for details regarding this project.  


### Project Structure

* `./src/qnetti` - Application code.
* `./test` - Unit tests for application code.
* `./script` - Scripts for numerical experiments, data collection, and plotting.
* `./data` - Stored data from numerical experiments.
* `./demos` - User oriented notebooks demoing the application of our code. 
* `./docs` - Source code for generating the static documentation pages.

